@@ -48,7 +48,7 @@
 
 static NAME_MASK x_esmtp_verb_mask_table[] = {
     EHLO_VERB_SMTPUTF8, SOPT_SMTPUTF8_REQUESTED,
-    EHLO_VERB_REQUIRETLS, SOPT_REQUIRETLS_ESMTP,
+    EHLO_VERB_REQTLS, SOPT_REQUIRETLS_ESMTP,
     0,
 };
 
