@@ -236,7 +236,6 @@ static int copy_segment(VSTREAM *qfile, VSTREAM *cleanup, PICKUP_INFO *info,
     char   *attr_value;
     char   *saved_attr;
     int     skip_attr;
-    ssize_t count;
 
     /*
      * Limit the input record size. All front-end programs should protect the
@@ -247,7 +246,7 @@ static int copy_segment(VSTREAM *qfile, VSTREAM *cleanup, PICKUP_INFO *info,
      * 
      * We must allow PTR records here because of "postsuper -r".
      */
-    for (count = 0; /* void */; count++) {
+    for (;;) {
 	if ((type = rec_get(qfile, buf, var_line_limit)) < 0
 	    || strchr(expected, type) == 0)
 	    return (file_read_error(info, type));
@@ -265,9 +264,6 @@ static int copy_segment(VSTREAM *qfile, VSTREAM *cleanup, PICKUP_INFO *info,
 	}
 	if (type == REC_TYPE_TIME)
 	    time_seen = 1;
-	if (type == REC_TYPE_SIZE && count > 5)
-	    /* Discard SIZE record not at beginning of segment. */
-	    continue;
 
 	/*
 	 * XXX Workaround: REC_TYPE_FILT (used in envelopes) == REC_TYPE_CONT
@@ -490,7 +486,7 @@ static int pickup_file(PICKUP_INFO *info)
 	cleanup_flags &= ~CLEANUP_FLAG_MILTER;
     else
 	cleanup_flags |= smtputf8_autodetect(MAIL_SRC_MASK_SENDMAIL);
-    /* TODO(wietse) REQUIRETLS? */
+    /* Use REQUIRETLS flag(s) in SIZE record. */
 
     cleanup = mail_connect_wait(MAIL_CLASS_PUBLIC, var_cleanup_service);
     if (attr_scan(cleanup, ATTR_FLAG_STRICT,
